@@ -111,4 +111,11 @@ def _matches_filters(
     obj: ty.BaseModel,
     filters: ty.Dict[str, ty.Union[str, int]],
 ) -> bool:
-    return all(getattr(obj, key) == value for key, value in filters.items())
+    return all(_is_equal(getattr(obj, key), value) for key, value in filters.items())
+
+
+def _is_equal(x: ty.Any, y: ty.Any) -> bool:
+    if isinstance(x, ty.UUID) or isinstance(y, ty.UUID):
+        return str(x) == str(y)
+    else:
+        return x == y
