@@ -1,6 +1,7 @@
 from datetime import datetime
 from pathlib import Path
 from types import ModuleType
+from uuid import UUID
 from typing import (
     Any,
     Callable,
@@ -52,4 +53,5 @@ __all__ = [
     "datetime",
     "BaseModel",
     "ModuleType",
+    "UUID",
 ]
